Mailinglist Archive: yast-commit (500 mails)

< Previous Next >
[yast-commit] r66358 - in /branches/tmp/lslezak/dbus-server: ./ package/ src/liby2dbus/ src/liby2dbus/src/ src/services/ src/services/SCR_service/ src/services/namespace_service/ src/services/namespace_service/d...
Author: lslezak
Date: Mon Oct 10 15:06:59 2011
New Revision: 66358

URL: http://svn.opensuse.org/viewcvs/yast?rev=66358&view=rev
Log:
merged changes from Trunk (r60961 to r66357)

Added:
branches/tmp/lslezak/dbus-server/src/liby2dbus/src/search_path.h
- copied unchanged from r66357,
trunk/dbus-server/src/liby2dbus/src/search_path.h
Modified:
branches/tmp/lslezak/dbus-server/ (props changed)
branches/tmp/lslezak/dbus-server/VERSION
branches/tmp/lslezak/dbus-server/package/ (props changed)
branches/tmp/lslezak/dbus-server/package/yast2-dbus-server.changes
branches/tmp/lslezak/dbus-server/src/liby2dbus/ (props changed)
branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusMsg.cc
branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusServerBase.cc
branches/tmp/lslezak/dbus-server/src/liby2dbus/src/Makefile.am
branches/tmp/lslezak/dbus-server/src/services/Makefile.am (props changed)
branches/tmp/lslezak/dbus-server/src/services/SCR_service/ (props changed)
branches/tmp/lslezak/dbus-server/src/services/namespace_service/ (props
changed)

branches/tmp/lslezak/dbus-server/src/services/namespace_service/doc/org.opensuse.yast.modules.yapi.samba.policy
(props changed)

branches/tmp/lslezak/dbus-server/src/services/namespace_service/testsuite/t5-params.py
branches/tmp/lslezak/dbus-server/yast2-dbus-server.spec.in

Modified: branches/tmp/lslezak/dbus-server/VERSION
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/VERSION?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--- branches/tmp/lslezak/dbus-server/VERSION (original)
+++ branches/tmp/lslezak/dbus-server/VERSION Mon Oct 10 15:06:59 2011
@@ -1 +1 @@
-2.18.1
+2.21.0

Modified: branches/tmp/lslezak/dbus-server/package/yast2-dbus-server.changes
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/package/yast2-dbus-server.changes?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--- branches/tmp/lslezak/dbus-server/package/yast2-dbus-server.changes
(original)
+++ branches/tmp/lslezak/dbus-server/package/yast2-dbus-server.changes Mon Oct
10 15:06:59 2011
@@ -1,4 +1,36 @@
-------------------------------------------------------------------
+Wed Jun 29 11:19:50 UTC 2011 - lslezak@xxxxxxx
+
+- properly distinguish between received empty map and empty list
+ (bnc#588593)
+- reenable tests during build
+- 2.21.0
+
+-------------------------------------------------------------------
+Mon Feb 7 14:49:13 UTC 2011 - lslezak@xxxxxxx
+
+- temporarily disable tests (see bnc#645381)
+
+-------------------------------------------------------------------
+Mon Oct 11 13:54:01 CEST 2010 - mvidner@xxxxxxx
+
+- Build fix: python-2.7 moved unittest to python-devel
+
+-------------------------------------------------------------------
+Thu Jul 15 11:05:35 UTC 2010 - lslezak@xxxxxxx
+
+- set PATH environment to the default if it's not set (bnc#617442)
+- 2.20.0
+
+-------------------------------------------------------------------
+Wed May 19 16:14:05 CEST 2010 - mvidner@xxxxxxx
+
+- Better fix: dbus_bool_t instead of int (bnc#606712).
+- Fixed retrieving boolean values on big-endian archs (bnc#606712).
+- Enabled the already existing test for this bug.
+- 2.18.2
+
+-------------------------------------------------------------------
Fri Sep 4 18:06:38 CEST 2009 - mvidner@xxxxxxx

- don't use ldconfig as a shell in postun

Modified: branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusMsg.cc
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusMsg.cc?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--- branches/tmp/lslezak/dbus-server/src/liby2dbus/src/Makefile.am (original)
+++ branches/tmp/lslezak/dbus-server/src/liby2dbus/src/Makefile.am Mon Oct 10
15:06:59 2011
@@ -8,7 +8,7 @@

liby2dbus_la_SOURCES = DBusMsg.cc DBusMsg.h DBusConn.cc DBusConn.h
DBusCaller.cc DBusCaller.h \
DBusServerBase.cc DBusServerBase.h DBusSignature.cc
DBusSignature.h \
- DBusArgument.cc DBusArgument.h
+ DBusArgument.cc DBusArgument.h search_path.h
if HAVE_POLKIT
liby2dbus_la_SOURCES += PolKit.cc PolKit.h
endif

Modified:
branches/tmp/lslezak/dbus-server/src/services/namespace_service/testsuite/t5-params.py
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/src/services/namespace_service/testsuite/t5-params.py?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
---
branches/tmp/lslezak/dbus-server/src/services/namespace_service/testsuite/t5-params.py
(original)
+++
branches/tmp/lslezak/dbus-server/src/services/namespace_service/testsuite/t5-params.py
Mon Oct 10 15:06:59 2011
@@ -78,6 +78,18 @@
lst = [1, 2, 3]
self.assertEqual(self.T.ParamList(lst), lst)

+ # test sending/receivng a map, test also empty map and list (bnc#588593)
+ def testMap(self):
+ map = {
+ "string" : True,
+ "list" : ["a", "b", "c"],
+ "map" : { "key" : "value"},
+ # python cannot guess signature for empty containers, set it explicitly
+ "empty_list" : dbus.Array([], "s"),
+ "empty_map" : dbus.Dictionary({}, "sv")
+ }
+ self.assertEqual(self.T.ParamMap(map), map)
+
#Term is not exported
# def testTerm(self):
# term = ["name", "two", "three"]

Modified: branches/tmp/lslezak/dbus-server/yast2-dbus-server.spec.in
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/yast2-dbus-server.spec.in?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--- branches/tmp/lslezak/dbus-server/yast2-dbus-server.spec.in (original)
+++ branches/tmp/lslezak/dbus-server/yast2-dbus-server.spec.in Mon Oct 10
15:06:59 2011
@@ -3,7 +3,8 @@

@HEADER@
Group: System/YaST
-License: GPL v2 or later
+License: GPL-2.0+
+Url: http://en.opensuse.org/Portal:YaST
# obviously
BuildRequires: gcc-c++
# needed for all yast packages
@@ -19,6 +20,8 @@

# for SCR DBus service
BuildRequires: dbus-1-devel dbus-1-x11 polkit-devel libxcrypt-devel
+# its tests
+BuildRequires: dbus-1-python python-devel

Summary: YaST2 - DBus Server


--- branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusMsg.cc (original)
+++ branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusMsg.cc Mon Oct 10
15:06:59 2011
@@ -386,8 +386,6 @@

DBusMessageIter array_it;

- YCPMap::const_iterator mit = map.begin();
-
std::string map_signature("{" + map_key_type + map_val_type + "}");

// open array container
@@ -796,7 +794,7 @@
{
if (type == DBUS_TYPE_BOOLEAN)
{
- bool b;
+ dbus_bool_t b; // not bool, bnc#606712
dbus_message_iter_get_basic(it, &b);
ret = YCPBoolean(b);
mismatch = false;
@@ -967,7 +965,7 @@
// TODO support more types
if (type == DBUS_TYPE_BOOLEAN)
{
- bool b;
+ dbus_bool_t b; // not bool, bnc#606712
dbus_message_iter_get_basic(it, &b);
ret = YCPBoolean(b);
}
@@ -986,9 +984,12 @@
// DBUS_TYPE_ARRAY is used for YCPList and YCPMap
y2debug("Reading RAW DBus array");

- // is the container a map or a list?
- // An empty map is indistinguishable from a list!
- if (dbus_message_iter_get_arg_type(&sub) == DBUS_TYPE_DICT_ENTRY)
+ // is the container a map or a list? => check the signature of the
iterator
+ // hash signature starts with '{', examples: list signature: "s", map
signature: "{sv}"
+ std::string cont_sig(dbus_message_iter_get_signature(&sub));
+ y2debug("Container signature: %s", cont_sig.c_str());
+
+ if (!cont_sig.empty() && cont_sig[0] == '{')
{
y2debug("Found a map");
ret = getYCPValueMap(&sub, Type::Any, Type::Unspec);

Modified: branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusServerBase.cc
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusServerBase.cc?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--- branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusServerBase.cc
(original)
+++ branches/tmp/lslezak/dbus-server/src/liby2dbus/src/DBusServerBase.cc Mon
Oct 10 15:06:59 2011
@@ -9,6 +9,7 @@

#include "DBusServerBase.h"
#include "DBusMsg.h"
+#include "search_path.h"

#include <ycp/y2log.h>

@@ -25,6 +26,9 @@
{
test_mode = testmode;
dbus_threads_init_default();
+
+ // set default PATH if not set
+ set_default_path();
}

DBusServerBase::~DBusServerBase()
@@ -141,7 +145,7 @@
// the time is over
if (!timeout_counter)
{
- y2debug("Timout reached");
+ y2debug("Timeout reached");

if (canFinish())
{

Modified: branches/tmp/lslezak/dbus-server/src/liby2dbus/src/Makefile.am
URL:
http://svn.opensuse.org/viewcvs/yast/branches/tmp/lslezak/dbus-server/src/liby2dbus/src/Makefile.am?rev=66358&r1=66357&r2=66358&view=diff
==============================================================================
--
To unsubscribe, e-mail: yast-commit+unsubscribe@xxxxxxxxxxxx
For additional commands, e-mail: yast-commit+help@xxxxxxxxxxxx

< Previous Next >
This Thread
  • No further messages